A container for a kind of change pattern that represents a commit that matches said pattern,
as well as a vector of Commit objects that match the pattern for that kind of change.
Data structure that contains a version with a major, minor, and patch number as well as a map
of commits that represent changes since the previous version.