ChangeList

Struct ChangeList 

pub struct ChangeList { /* private fields */ }
Represents a list of change formats to use while analyzing commits.

Implementations

Source

impl ChangeList

pub fn new(changes: Vec<Change>) -> Self

pub fn check(&self, commit: &Commit) -> Option<&Change>

Checks a commit to see if it matches any of the changes in this list and returns the kind of change it matched.