pub struct CommitBucket { /* private fields */ }Expand description
A container for a kind of change pattern that represents a commit that matches said pattern, as well as a vector of Commit objects that match the pattern for that kind of change.
Implementations
Sourceimpl CommitBucket
Auto-generated by derive_getters::Getters.
impl CommitBucket
Auto-generated by derive_getters::Getters.