pub struct Version { /* private fields */ }Expand description
Data structure that contains a version with a major, minor, and patch number as well as a map of commits that represent changes since the previous version.
Implementations
Sourceimpl Version
impl Version
Sourcepub fn get(&self) -> String
pub fn get(&self) -> String
Gets the version in string form. Formatted, “v(major).(minor).(patch)”
Sourcepub fn short(&self) -> String
pub fn short(&self) -> String
Gets the version in short string form. Formatted, “(major).(minor).(patch)”
Sourcepub fn parse(version: &str) -> Option<(u32, u32, u32)>
pub fn parse(version: &str) -> Option<(u32, u32, u32)>
Parse a string into the appropriate version numbers. Returns a tuple containing the major, minor, and patch version numbers extracted from the string, if available.
pub fn new(major: u32, minor: u32, patch: u32, changes: CommitMap) -> Self