Crate semver_common

Crate semver_common 

Modules

mock

Structs

Alert
Alert is a wrapper for all the various error types that may be returned by various crate functions.
Change
A pattern that represents a type of change based on a commit message.
ChangeList
Represents a list of change formats to use while analyzing commits.
Commit
CommitBucket
A container for a kind of change pattern that represents a commit that matches said pattern, as well as a vector of Commit objects that match the pattern for that kind of change.
CommitMap
PluginConfig
Version
Data structure that contains a version with a major, minor, and patch number as well as a map of commits that represent changes since the previous version.

Functions

run_command