Skip to main contentModule git
Source - auth
- commit_all
- Stages all changes in git and commits those changes with a supplied message.
- fetch
- Fetch from the remote repository to ensure commit history is updated.
- get_commits
- Gets the commits in the history of the supplied branch.
Returns as a vector of Commit objects.
- latest_tag
- Gets the latest git tag from the git repository.
- push
- Pushes any commited changes in git to the authenticated remote repository.
- tag
- Creates a new git tag with a supplied name and message.