Version

Struct Version 

pub struct Version { /* private fields */ }
Data structure that contains a version with a major, minor, and patch number as well as a map of commits that represent changes since the previous version.

Implementations

Source

impl Version

Auto-generated by derive_getters::Getters.

pub fn major(&self) -> &u32

Get field major from instance of Version.

pub fn minor(&self) -> &u32

Get field minor from instance of Version.

pub fn patch(&self) -> &u32

Get field patch from instance of Version.

pub fn changes(&self) -> &CommitMap

Get field changes from instance of Version.

Source

impl Version

pub fn get(&self) -> String

Gets the version in string form. Formatted, “v(major).(minor).(patch)”

pub fn short(&self) -> String

Gets the version in short string form. Formatted, “(major).(minor).(patch)”

pub fn parse(version: &str) -> Option<(u32, u32, u32)>

Parse a string into the appropriate version numbers. Returns a tuple containing the major, minor, and patch version numbers extracted from the string, if available.

pub fn new(major: u32, minor: u32, patch: u32, changes: CommitMap) -> Self